/**
 * Configuration functionality.
 */

#include "Configuration.h"

#if USE_HARDCODED_CONFIGURATION != 0

#define NUM_DECODER_CORES (4)

static void configureDecoder(int decoderIndex, int coreId)
{
    DspDecoderConfiguration *decoderConfiguration = &((DspConfiguration*) CONFIGURATION_ADDRESS_ON_DSP)->decoderConfigurations[decoderIndex];

    int i;
    for (i = 0; i < NUM_DECODER_CORES; i++) {
        decoderConfiguration->coreIds[i] = coreId + i;
    }
    decoderConfiguration->coreIds[i] = -1;

    decoderConfiguration->decoderType = H264HP_DECODER;
    decoderConfiguration->inputBufferAddress = decoderIndex;
    decoderConfiguration->inputFrameRate = 25;
    decoderConfiguration->inputWidth = 720;
    decoderConfiguration->inputHeight = 576;
}

#endif

const DspConfiguration* Configuration_get()
{
    DspConfiguration* configuration = (DspConfiguration*) CONFIGURATION_ADDRESS_ON_DSP;

#if USE_HARDCODED_CONFIGURATION != 0
    if (configuration->marker != 0xABBA) {
        configuration->marker = 0xABBA;

        configuration->decodersCount = 1;
        configureDecoder(0, 0);
    }
#endif

    return configuration;
}

int Configuration_calculateNumberOfCores(const int32_t* coreIds)
{
    int i;
    int count = 0;

    for (i = 0; i < CORES_PER_DSP; i++) {
        if (coreIds[i] == -1) {
            break;
        }
        count++;
    }

    return count;
}
