#include <xdc/std.h>
#include <ti/ipc/GateMP.h>
#include <ti/sysbios/knl/Task.h>
#include "Common.h"

static const char* TRANSCODE_COMPONENT_GATE_NAME = "tcGate";

extern cregister volatile unsigned int DNUM;

static GateMP_Handle transcodeComponentGate = NULL;

static GateMP_Handle initGate(const char* name, GateMP_LocalProtect localProtect) {
    GateMP_Handle gate = NULL;

    if (DNUM == 0) {
        GateMP_Params gateParams;
        GateMP_Params_init(&gateParams);
        gateParams.name = (char*) name;
        gateParams.localProtect = localProtect;
        gate = GateMP_create(&gateParams);
    } else {
        while (1) {
            int result = GateMP_open((char*) name, &gate);

            if (result == GateMP_E_NOTFOUND) {
                Task_sleep(1);
            } else if (result == GateMP_S_SUCCESS) {
                break;
            } else {
                return NULL;
            }
        }
    }

    return gate;
}

ResultCode GlobalGates_init()
{
    transcodeComponentGate = initGate(TRANSCODE_COMPONENT_GATE_NAME, GateMP_LocalProtect_TASKLET);

    if (transcodeComponentGate == NULL) {
        return ResultCode_Error;
    }

    return ResultCode_Ok;
}

GateMP_Handle GlobalGates_getTranscodeComponentGate()
{
    return transcodeComponentGate;
}
