/**
 * Multicore API for algorithms (i.e. decoders and encoders).
 */

#include <string.h>

#include <xdc/std.h>
#include <xdc/runtime/Error.h>
#include <xdc/runtime/Memory.h>
#include <ti/sysbios/family/c66/Cache.h>
#include <ti/sysbios/knl/Task.h>
#include <ti/sysbios/knl/Clock.h>
#include <ti/xdais/xdas.h>

#include <xdc/cfg/global.h>

#include "GlobalGates.h"
#include "DspCommonTypes.h"
#include "Heaps.h"
#include "MulticoreApi.h"

TranscodeComponent* MulticoreApi_transcodeComoponent = NULL;
static int MulticoreApi_msmcHeapEnabled = 0;

void MulticoreApi_useMsmcHeap(int enable)
{
    MulticoreApi_msmcHeapEnabled = enable;
}

void MulticoreApi_swbarr(int32_t coreID, int32_t swbarr_id, uint32_t swbarr_cnt)
{
    TranscodeComponent_swbarr(MulticoreApi_transcodeComoponent, swbarr_id, swbarr_cnt);
}

int32_t* MulticoreApi_shmmap(int32_t coreID, int32_t shmem_key, int32_t shmem_size, uint32_t attr, int32_t alignment)
{
    return TranscodeComponent_shmmap(MulticoreApi_transcodeComoponent, shmem_key, shmem_size,
            ((attr == IVIDMC_SHMEM_ATTRS_SL2) && !MulticoreApi_msmcHeapEnabled) ? IVIDMC_SHMEM_ATTRS_DDR_CACHED : attr, alignment);
}

int32_t MulticoreApi_shmmunmap(int32_t coreID, int32_t shmem_key, int32_t *shmem_base)
{
    TranscodeComponent_shmmunmap(MulticoreApi_transcodeComoponent, shmem_key);
    return 0;
}

void MulticoreApi_syncAllSharedMemoryDummy()
{
}

int32_t MulticoreApi_shmmap_sync(int32_t coreID, int32_t shmem_key, int32_t *shmem_base)
{
    TranscodeComponent_shmmap_sync(MulticoreApi_transcodeComoponent, shmem_key);
    return 0;
}

void MulticoreApi_swbarrDummy(int32_t coreID, int32_t swbarr_id, uint32_t swbarr_cnt)
{
}

int32_t* MulticoreApi_shmmapDummy(int32_t coreID, int32_t shmem_key, int32_t shmem_size, uint32_t attr, int32_t alignment)
{
    return NULL;
}

int32_t MulticoreApi_shmmunmapDummy(int32_t coreID, int32_t shmem_key, int32_t *shmem_base)
{
    return 0;
}

int32_t MulticoreApi_shmmap_syncDummy(int32_t coreID, int32_t shmem_key, int32_t *shmem_base)
{
    return 0;
}

void* MulticoreApi3_keyCreate(uint8_t* name, int32_t user_id, IVIDMC3_KEY_SPACE_e key_space, int32_t num_users, int32_t* user_ids, IVIDMC3_KeyCfg_t* cfg)
{
    return TranscodeComponent_keyCreate(MulticoreApi_transcodeComoponent, name, user_id, key_space, num_users, user_ids, cfg);
}

int32_t MulticoreApi3_shmSyncWait(int32_t user_id, void* shmemHandle, int32_t* shmem_transid)
{
    return 0;
}

int32_t MulticoreApi3_lockAcquireDummy(int32_t user_id, void* lockHandle)
{
    return IVIDMC3_LOCK_ERROR_NONE;
}

int32_t MulticoreApi3_lockReleaseDummy(int32_t user_id, void* lockHandle)
{
    return IVIDMC3_LOCK_ERROR_NONE;
}

int32_t MulticoreApi3_lockCheckDummy(int32_t user_id, void* lockHandle)
{
    return IVIDMC3_LOCK_ERROR_NONE;
}

int32_t MulticoreApi3_barrWaitDummy(int32_t user_id, void* barrHandle)
{
    return IVIDMC3_BARR_ERROR_NONE;
}
